<?php

namespace Drupal\cached_computed_field\Event;

use Symfony\Component\EventDispatcher\Event;

/**
 * Event that fires when the cache lifetime of a cached computed field expires.
 */
class RefreshExpiredFieldEvent extends Event implements RefreshExpiredFieldEventInterface {

  /**
   * The entity type ID of the entity that contains the expired field.
   *
   * @var string
   */
  protected $entityTypeId;

  /**
   * The ID of the entity that contains the expired field.
   *
   * @var mixed
   */
  protected $entityId;

  /**
   * The name of the expired field.
   *
   * @var string
   */
  protected $fieldName;

  /**
   * The UNIX time stamp indicating when this field has expired.
   *
   * @var int
   */
  protected $expireTime;

  /**
   * Constructs a new RefreshExpiredFieldEvent object.
   *
   * @param string $entity_type_id
   *   The entity type ID of the entity that contains the expired field.
   * @param mixed $entity_id
   *   The ID of the entity that contains the expired field.
   * @param string $field_name
   *   The name of the expired field.
   * @param int $expire_time
   *   The UNIX time stamp indicating when this field has expired.
   */
  public function __construct($entity_type_id, $entity_id, $field_name, $expire_time) {
    $this->entityTypeId = $entity_type_id;
    $this->entityId = $entity_id;
    $this->fieldName = $field_name;
    $this->expireTime = $expire_time;
  }

  /**
   * {@inheritdoc}
   */
  public function getEntityTypeId() {
    return $this->entityTypeId;
  }

  /**
   * {@inheritdoc}
   */
  public function getEntityId() {
    return $this->entityId;
  }

  /**
   * {@inheritdoc}
   */
  public function getFieldName() {
    return $this->fieldName;
  }

  /**
   * {@inheritdoc}
   */
  public function getExpireTime() {
    return $this->expireTime;
  }

}
