<?php

namespace Drupal\cached_computed_field\Event;

/**
 * Interface for events that fire when cached computed fields expire.
 */
interface RefreshExpiredFieldEventInterface {

  /**
   * The event name.
   */
  const EVENT_NAME = 'cached_computed_field.refresh_expired_field';

  /**
   * Returns the entity type ID of the entity that contains the expired field.
   *
   * @return string
   *   The entity type ID.
   */
  public function getEntityTypeId();

  /**
   * Returns the ID of the entity that contains the expired field.
   *
   * @return mixed
   *   The ID of the entity that contains the expired field.
   */
  public function getEntityId();

  /**
   * Returns the name of the expired field.
   *
   * @return string
   *   The name of the expired field.
   */
  public function getFieldName();

  /**
   * Returns the UNIX time stamp indicating when this field has expired.
   *
   * @return int
   *   The UNIX time stamp indicating when this field has expired.
   */
  public function getExpireTime();

}
