<?php

namespace Drupal\cached_computed_field\EventSubscriber;

use Drupal\cached_computed_field\Event\RefreshExpiredFieldEventInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Interface for event subscribers that refresh expired cached computed fields.
 */
interface RefreshExpiredFieldSubscriberInterface extends EventSubscriberInterface {

  /**
   * Event subscriber that reacts to the RefreshExpiredFieldEvent.
   *
   * @param \Drupal\cached_computed_field\Event\RefreshExpiredFieldEventInterface $event
   *   The triggering event.
   */
  public function refreshExpiredField(RefreshExpiredFieldEventInterface $event);

  /**
   * Returns the entity that contains the expired field.
   *
   * @param \Drupal\cached_computed_field\Event\RefreshExpiredFieldEventInterface $event
   *   The triggering event.
   *
   * @return \Drupal\Core\Entity\ContentEntityInterface
   *   The entity.
   */
  public function getEntity(RefreshExpiredFieldEventInterface $event);

  /**
   * Returns the field definition of the expired field.
   *
   * @param \Drupal\cached_computed_field\Event\RefreshExpiredFieldEventInterface $event
   *   The field definition.
   *
   * @return \Drupal\Core\Field\FieldDefinitionInterface
   *   The definition of the field.
   */
  public function getFieldDefinition(RefreshExpiredFieldEventInterface $event);

  /**
   * Returns the expired data that is currently cached in the field.
   *
   * @param \Drupal\cached_computed_field\Event\RefreshExpiredFieldEventInterface $event
   *   The triggering event.
   *
   * @return mixed
   *   The data.
   */
  public function getExpiredFieldValue(RefreshExpiredFieldEventInterface $event);

  /**
   * Updates the field with the given value, and sets the cache expiration time.
   *
   * Call this with the calculated value. It will write the value to the
   * database and reset the cache lifetime.
   *
   * @param \Drupal\cached_computed_field\Event\RefreshExpiredFieldEventInterface $event
   *   The triggering event.
   *
   * @param mixed $value
   *   The value to set.
   */
  public function updateFieldValue(RefreshExpiredFieldEventInterface $event, $value);

  /**
   * Returns whether or not the field needs to be refreshed.
   *
   * It is possible a field value has already been refreshed in the time between
   * it was added to the queue and the moment the event fires.
   *
   * @param \Drupal\cached_computed_field\Event\RefreshExpiredFieldEventInterface $event
   *   The triggering event.
   *
   * @return bool
   *   TRUE if the cache lifetime of the field has expired, or if the field is
   *   new and has not been populated with a value yet.
   */
  public function fieldNeedsRefresh(RefreshExpiredFieldEventInterface $event);

  /**
   * Returns the expired field instance.
   *
   * @param \Drupal\cached_computed_field\Event\RefreshExpiredFieldEventInterface $event
   *   The triggering event.
   *
   * @return \Drupal\Core\Field\FieldItemListInterface
   *   The field instance.
   */
  public function getField(RefreshExpiredFieldEventInterface $event);

}
