<?php

namespace Drupal\cached_computed_field\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Settings form for the Cached Computed Field module.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'cached_computed_field.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cached_computed_field_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('cached_computed_field.settings');

    $form['item_limit'] = [
      '#type' => 'number',
      '#title' => $this->t('Item limit'),
      '#description' => $this->t('The maximum number of items to queue for processing during a single cron run. Set to -1 to queue all items. Note that cron processing is time limited so it is not guaranteed that this number of items will effectively be processed.'),
      '#default_value' => $config->get('item_limit'),
      '#required' => TRUE,
      '#min' => -1,
    ];

    $form['time_limit'] = [
      '#type' => 'number',
      '#title' => $this->t('Time limit'),
      '#description' => $this->t('The time, in seconds, that is allotted to processing expired items during a single cron run. This can be used to control server load.'),
      '#default_value' => $config->get('time_limit'),
      '#required' => TRUE,
      '#min' => 1,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);

    $item_limit = $form_state->getValue('item_limit');
    $time_limit = $form_state->getValue('time_limit');

    if (filter_var($item_limit, FILTER_VALIDATE_INT) === FALSE) {
      $form_state->setErrorByName('item_limit', $this->t('The item limit must be an integer value.'));
    }
    elseif ($item_limit < -1 || $item_limit == 0) {
      $form_state->setErrorByName('item_limit', $this->t('The item limit must be either "-1" or a positive number.'));
    }
    if (filter_var($time_limit, FILTER_VALIDATE_INT) === FALSE) {
      $form_state->setErrorByName('time_limit', $this->t('The time limit must be an integer value.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('cached_computed_field.settings')
      ->set('item_limit', (int) $form_state->getValue('item_limit'))
      ->set('time_limit', (int) $form_state->getValue('time_limit'))
      ->save();
  }

}
