<?php

namespace Drupal\cached_computed_field\Plugin\QueueWorker;

use Drupal\cached_computed_field\Event\RefreshExpiredFieldEvent;
use Drupal\cached_computed_field\Event\RefreshExpiredFieldEventInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;

/**
 * Updates cached computed fields of which the cache lifetime has expired.
 *
 * @QueueWorker(
 *   id = "cached_computed_field_expired_fields",
 *   title = @Translation("Refresh expired cached computed fields"),
 *   cron = {"time" = 60}
 * )
 */
class RefreshExpiredFields extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * The event dispatcher.
   *
   * @var \Symfony\Component\EventDispatcher\EventDispatcherInterface
   */
  protected $eventDispatcher;

  /**
   * Constructs a RefreshExpiredFields queue worker.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Symfony\Component\EventDispatcher\EventDispatcherInterface $event_dispatcher
   *   The event dispatcher.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, EventDispatcherInterface $event_dispatcher) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->eventDispatcher = $event_dispatcher;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('event_dispatcher')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {
    // Fire an event that allows to update the expired data through custom code.
    $event = new RefreshExpiredFieldEvent($data['entity_type'], $data['entity_id'], $data['field_name'], $data['expire']);
    $this->eventDispatcher->dispatch(RefreshExpiredFieldEventInterface::EVENT_NAME, $event);
  }

}
